==> gitlab-tools-v0.2.0.tar.gz: gitlab-tools/gitlab-tools-install.sh <==
#!/bin/bash -e
#
# gitlab-tools:gitlab-tools-install.sh
#
set -u
set -o pipefail

PROJECT_HOME="$( dirname "$( realpath "${BASH_SOURCE[0]}" )" )"
declare -r PROJECT_HOME

# shellcheck disable=SC1090
source "${PROJECT_HOME}/bin/install-config.sh" || exit 1
# shellcheck disable=SC1090
source "${PROJECT_HOME}/apis/bash-common-api/bash-common-api.sh" || exit 1
# shellcheck disable=SC1090
source "${PROJECT_HOME}/apis/install-api/install-api.sh" || exit 1

function usage {
  cat <<EOF
Usage:

  $( basename "${BASH_SOURCE[0]}" ) --help
  $( basename "${BASH_SOURCE[0]}" ) [--skip-update] [--package-manager PMEXE]

Options:
  -h,       --help  Display help message and exit.
  -S,       --skip-update
                    Skip package manager update
  -P PMEXE, --package-manager PMEXE
                    Force package manger

EOF
}

function exit_if_not_sudo_H {
  local home_expected=
  home_expected="$( grep "^${USER}:" /etc/passwd | cut -d ':' -f6 )"

  if [ "${home_expected}" != "${HOME}" ] ; then
    echofatal 'sudo -H is required'
    exit 1
  fi
}

function install_python_gitlab { # (could be at user level?)
  if ! command -v pip3 >/dev/null ; then
    install_install_if_needed "${param_pkg_manager}" 'python3-pip'
  fi

  # pip3 install --upgrade python-gitlab || exit 1
  # python3 -m pip install --upgrade python-gitlab  configparser==3.5.0 virtualenv || exit 1
  python3 -m pip install --upgrade setuptools || exit 1
  python3 -m pip install --upgrade python-gitlab configparser==3.5.0 || exit 1
}

function main {
  local param=
  local param_pkg_manager=
  local param_skip_update=

  while [ $# -gt 0 ] ; do
    param="$1"
    shift

    case "${param}" in
      '-h'|'--help') usage ; exit 0 ;;
      '-P'|'--package-manager') param_pkg_manager="$( P "$@" )" && shift ;;
      '-S'|'--skip-update') param_skip_update='true' ;;

      *)
        echofatal "Unknown option: '${param}'"
        usage >&2
        exit 1
        ;;
    esac
  done

  exit_if_not_root

  exit_if_not_sudo_H

  remove_previous_version_before_install

  if [ "${param_skip_update}" != 'true' ] ; then
    install_update "${param_pkg_manager}"
  fi
  install_install_if_needed "${param_pkg_manager}" "${INSTALL_PACKAGES[@]}"

  install_python_gitlab

  install_main
}

main "$@"

==> gitlab-tools-v0.2.1.tar.gz: gitlab-tools/gitlab-tools-install.sh <==
#!/bin/bash -e
#
# gitlab-tools:gitlab-tools-install.sh
#
set -u
set -o pipefail

PROJECT_HOME="$( dirname "$( realpath "${BASH_SOURCE[0]}" )" )"
declare -r PROJECT_HOME

# shellcheck disable=SC1090
source "${PROJECT_HOME}/bin/install-config.sh" || exit 1
# shellcheck disable=SC1090
source "${PROJECT_HOME}/apis/bash-common-api/bash-common-api.sh" || exit 1
# shellcheck disable=SC1090
source "${PROJECT_HOME}/apis/install-api/install-api.sh" || exit 1

function usage {
  cat <<EOF
Usage:

  $( basename "${BASH_SOURCE[0]}" ) --help
  $( basename "${BASH_SOURCE[0]}" ) [--skip-update] [--package-manager PMEXE]

Options:
  -h,       --help  Display help message and exit.
  -S,       --skip-update
                    Skip package manager update
  -P PMEXE, --package-manager PMEXE
                    Force package manager binary name

EOF
}

function exit_if_not_sudo_H {
  local home_expected=
  home_expected="$( grep "^${USER}:" /etc/passwd | cut -d ':' -f6 )"

  if [ "${home_expected}" != "${HOME}" ] ; then
    echofatal 'sudo -H is required'
    exit 1
  fi
}

function install_python_gitlab { # (could be at user level?)
  if ! command -v pip3 >/dev/null ; then
    install_install_if_needed "${param_pkg_manager}" 'python3-pip'
  fi

  # pip3 install --upgrade python-gitlab || exit 1
  # python3 -m pip install --upgrade python-gitlab  configparser==3.5.0 virtualenv || exit 1
  python3 -m pip install --upgrade setuptools || exit 1
  python3 -m pip install --upgrade python-gitlab configparser==3.5.0 || exit 1
}

function main {
  local param=
  local param_pkg_manager=
  local param_skip_update=

  while [ "$#" -gt 0 ] ; do
    param="$1"
    shift

    case "${param}" in
      '-h'|'--help') usage ; exit 0 ;;
      '-P'|'--package-manager') param_pkg_manager="$( P "$@" )" && shift ;;
      '-S'|'--skip-update') param_skip_update='true' ;;

      *)
        echofatal "Unknown option: '${param}'"
        usage >&2
        exit 1
        ;;
    esac
  done

  exit_if_not_root

  exit_if_not_sudo_H

  remove_previous_version_before_install

  if [ "${param_skip_update}" != 'true' ] ; then
    install_update "${param_pkg_manager}"
  fi
  install_install_if_needed "${param_pkg_manager}" "${INSTALL_PACKAGES[@]}"

  install_python_gitlab

  install_main
}

main "$@"
